// Author 		: F. de la Parra
// Date			: March, 2019
// Version		: 1.0

public class Applicant extends Person implements Identifiable, Comparable {
	
	private int score;
	private String fullName;
	private String occupation;
	
	// Default constructor.
	public Applicant() {
		super.setUniqueId(999999);
		score = 0;
		fullName = "";
		occupation = "";
	}
	
	// Full parameter constructor.
	public Applicant(int newId, int newScore, String newFullName, String newOccupation) {
		super.setUniqueId(newId);
		score = newScore;
		fullName = newFullName;
		occupation = newOccupation;
	}
	
	// Accessor methods.
	
	public int getScore() {
		return score;
	}
	
	public String getFullName() {
		return fullName;
	}
	
	// Mutator methods.
	
	public void setScore(int newScore) {
		score = newScore;
	}

	public void setFullName(String newFullName) {
		fullName = newFullName;
	}
	
	// BEHAVIOUR METHODS
	
	// Basic methods.
	
	public String toString() {
		return "uniqueId = " + getUniqueId() + "\n" +
			   "score = " + score + "\n" +
			   "fullName = " + fullName;
	}
	
	// Application behaviour methods.
	
	// The 'Identifiable' interface makes the implementation of this method mandatory.	
	public void displayInfo(int id) {
		System.out.println("Information available for " + id + " is:");
		System.out.println("Name \t\t:" + fullName);
		System.out.println("Occupation \t:" + occupation);
		System.out.println("Score \t\t:" + score);
	}
	
	// The 'Identifiable' interface makes the implementation of this method mandatory.
	public void updateIdType(String pIdType) {
		try {
			// Convert 'string' pIdType to 'enumerated value' tempPIdType.
			personIdType tempPIdType = personIdType.valueOf(pIdType.toUpperCase());
			if (tempPIdType.equals(personIdType.ANONYMOUS))
				setUniqueId(99999999);
			else if (tempPIdType.equals(personIdType.IDENTIFIED)) {
				if (getUniqueId() == 99999999) {
					Object tempObject = new Object();
					setUniqueId(tempObject.hashCode());
				}
			}
		}
		catch(IllegalArgumentException e){
			System.out.println("\n'" + pIdType + "' is an invalid person id type!");
			System.out.println("Program aborted!");
			System.exit(0);
		}
	}

	// The Java API 'Comparable' interface makes the implementation of this method mandatory.
	public int compareTo(Object otherItem) {
		Applicant otherObject = (Applicant)otherItem;
		if (otherItem == null)
			return -9; 
		else if (otherObject.getScore() > score)
			return -1;
		else if (otherObject.getScore() < score)
			return 1;
		return 0;
	}
}