// Author 		: F. de la Parra
// Date			: March, 2019
// Version		: 1.0

// 'Person' is an abstract class with abstract methods (i.e., 'updateIdType').
// It just identifies a person by a number or 'anonymous'.
// This class cannot be instantiated. Attributes in this class can only be updated
// through classes derived from this class.
public abstract class Person {
	
	private int uniqueId;
	private String idType;		// idType can be 'anonymous' or 'identified'.
	
	// Accessor methods to be used primarily by derived classes.
	
	public int getUniqueId() {
		return uniqueId;
	}
	
	public String getIdType() {
		return idType;
	}
	
	public void setUniqueId(int newUniqueId) {
		uniqueId = newUniqueId;
	}
	
	// Mutator methods to be used primarily by derived classes.
	
	public void setIdType(String newIdType) {
		idType = newIdType;
	}
	
	// Abstract method to update a person's unique identifier.
	// This method is to be implemented in a derived class.
	public abstract void updateIdType(String pIdType);
	
}